@@ -57,15 +57,28 @@ GQuark pygobject_instance_data_key;
 void
 pygobject_data_free(PyGObjectData *data)
 {
-    PyGILState_STATE state = pyglib_gil_state_ensure();
+    /* This function may be called after the python interpreter has already
+     * been shut down. If this happens, we cannot do any python calls, so just
+     * free the memory. */
+    PyGILState_STATE state;
+    PyThreadState *_save = NULL;
+
     GSList *closures, *tmp;
-    Py_DECREF(data->type);
+
+    if (Py_IsInitialized()) {
+	state = pyglib_gil_state_ensure();
+	Py_DECREF(data->type);
+	/* We cannot use pyg_begin_allow_threads here because this is inside
+	 * a branch. */
+	if (pyg_threads_enabled)
+	    _save = PyEval_SaveThread();
+    }
+
     tmp = closures = data->closures;
 #ifndef NDEBUG
     data->closures = NULL;
     data->type = NULL;
 #endif
-    pyg_begin_allow_threads;
     while (tmp) {
  	GClosure *closure = tmp->data;
  
@@ -74,13 +87,17 @@ pygobject_data_free(PyGObjectData *data)
  	tmp = tmp->next;
  	g_closure_invalidate(closure);
     }
-    pyg_end_allow_threads;
  
     if (data->closures != NULL)
  	g_warning("invalidated all closures, but data->closures != NULL !");
 
     g_free(data);
-    pyglib_gil_state_release(state);
+
+    if (Py_IsInitialized()) {
+	if (pyg_threads_enabled)
+	    PyEval_RestoreThread(_save);
+	pyglib_gil_state_release(state);
+    }
 }
 
 static inline PyGObjectData *
@@ -1683,6 +1700,48 @@ pygobject_thaw_notify(PyGObject *self, PyObject *args)
     return Py_None;
 }
 
+static PyObject *
+pygobject_get_data(PyGObject *self, PyObject *args)
+{
+    char *key;
+    GQuark quark;
+    PyObject *data;
+
+    g_warning("GObject.get_data() and set_data() are deprecated. Use normal Python attributes instead");
+
+    if (!PyArg_ParseTuple(args, "s:GObject.get_data", &key))
+	return NULL;
+    
+    CHECK_GOBJECT(self);
+    
+    quark = g_quark_from_string(key);
+    data = g_object_get_qdata(self->obj, quark);
+    if (!data) data = Py_None;
+    Py_INCREF(data);
+    return data;
+}
+
+static PyObject *
+pygobject_set_data(PyGObject *self, PyObject *args)
+{
+    char *key;
+    GQuark quark;
+    PyObject *data;
+
+    g_warning("GObject.get_data() and set_data() are deprecated. Use normal Python attributes instead");
+
+    if (!PyArg_ParseTuple(args, "sO:GObject.set_data", &key, &data))
+	return NULL;
+    
+    CHECK_GOBJECT(self);
+    
+    quark = g_quark_from_string(key);
+    Py_INCREF(data);
+    g_object_set_qdata_full(self->obj, quark, data, pyg_destroy_notify);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 pygobject_connect(PyGObject *self, PyObject *args)
 {
@@ -2286,6 +2345,8 @@ static PyMethodDef pygobject_methods[] = {
     { "freeze_notify", (PyCFunction)pygobject_freeze_notify, METH_VARARGS },
     { "notify", (PyCFunction)pygobject_notify, METH_VARARGS },
     { "thaw_notify", (PyCFunction)pygobject_thaw_notify, METH_VARARGS },
+    { "get_data", (PyCFunction)pygobject_get_data, METH_VARARGS },
+    { "set_data", (PyCFunction)pygobject_set_data, METH_VARARGS },
     { "connect", (PyCFunction)pygobject_connect, METH_VARARGS },
     { "connect_after", (PyCFunction)pygobject_connect_after, METH_VARARGS },
     { "connect_object", (PyCFunction)pygobject_connect_object, METH_VARARGS },
