@@ -87,12 +87,12 @@ class _VariantCreator(object):
         format = format[1:]  # eat the '('
         builder = GLib.VariantBuilder.new(variant_type_from_string('r'))
         if args is not None:
-            if not args or type(args[0]) != type(()):
-                raise (TypeError, 'expected tuple argument')
+            if not args or not isinstance(args[0], tuple):
+                raise TypeError('expected tuple argument')
 
             for i in range(len(args[0])):
                 if format.startswith(')'):
-                    raise (TypeError, 'too many arguments for tuple signature')
+                    raise TypeError('too many arguments for tuple signature')
 
                 (v, format, _) = self._create(format, args[0][i:])
                 builder.add_value(v)
@@ -222,7 +222,7 @@ class Variant(GLib.Variant):
         # tuple
         if self.get_type_string().startswith('('):
             res = [self.get_child_value(i).unpack()
-                    for i in range(self.n_children())]
+                   for i in range(self.n_children())]
             return tuple(res)
 
         # dictionary
