@@ -396,7 +396,13 @@ __all__.append('Builder')
 
 class Window(Gtk.Window):
     def __init__(self, type=Gtk.WindowType.TOPLEVEL, **kwds):
-        Gtk.Window.__init__(self, type=type, **kwds)
+        # type is a construct-only property; if it is already set (e. g. by
+        # GtkBuilder), do not try to set it again and just ignore it
+        try:
+            self.get_property('type')
+            Gtk.Window.__init__(self, **kwds)
+        except TypeError:
+            Gtk.Window.__init__(self, type=type, **kwds)
 
 Window = override(Window)
 __all__.append('Window')
@@ -477,7 +483,7 @@ class MessageDialog(Gtk.MessageDialog, Dialog):
                  message_format=None,
                  **kwds):
 
-        if message_format != None:
+        if message_format:
             kwds['text'] = message_format
 
         # type keyword is used for backwards compat with PyGTK
@@ -555,11 +561,11 @@ class RecentChooserDialog(Gtk.RecentChooserDialog):
                  **kwds):
 
         Gtk.RecentChooserDialog.__init__(self,
-                recent_manager=manager,
-                title=title,
-                parent=parent,
-                buttons=buttons,
-                **kwds)
+                                         recent_manager=manager,
+                                         title=title,
+                                         parent=parent,
+                                         buttons=buttons,
+                                         **kwds)
 
 RecentChooserDialog = override(RecentChooserDialog)
 __all__.append('RecentChooserDialog')
@@ -713,7 +719,7 @@ class TextIter(Gtk.TextIter):
 
     def forward_search(self, string, flags, limit):
         success, match_start, match_end = super(TextIter, self).forward_search(string,
-            flags, limit)
+                                                                               flags, limit)
         if success:
             return (match_start, match_end)
         else:
@@ -721,7 +727,7 @@ class TextIter(Gtk.TextIter):
 
     def backward_search(self, string, flags, limit):
         success, match_start, match_end = super(TextIter, self).backward_search(string,
-            flags, limit)
+                                                                                flags, limit)
         if success:
             return (match_start, match_end)
         else:
@@ -1139,7 +1145,7 @@ class TreeModelRow(object):
             if len(indexList) != len(value):
                 raise ValueError(
                     "attempt to assign sequence of size %d to slice of size %d"
-                        % (len(value), len(indexList)))
+                    % (len(value), len(indexList)))
 
             for i, v in enumerate(indexList):
                 self.model.set_value(self.iter, v, value[i])
